@@ -9,7 +9,8 @@ Usage:
 Examples:
   igloo my_file.txt
   igloo -f private < my_code.py
-  echo 'hello world!' | igloo
+  echo 'hello world!' | igloo -s hello
+  igloo -sd test.log | grep foo
 
 Arguments:
   FILENAME                      The file to copy. If in uploading mode
@@ -34,7 +35,7 @@ Options:
 
 """
 
-__version__ = '0.0.15'
+__version__ = '0.0.16'
 
 
 from ConfigParser import NoSectionError, SafeConfigParser
